@@ -421,13 +421,13 @@ static struct device_info g_devs_info[] = {
         DM_LINKX                                           /* dev_type */
     },
     {
-        DeviceArcusE, // dm_id
-        0xb200,       // hw_dev_id (other versions 0x6f,0x73)
-        -1,           // hw_rev_id
-        -1,           // sw_dev_id
-        "ArcusE",     // name
-        -1,           // port_num
-        DM_RETIMER    // dev_type
+        DeviceArcusE, /* dm_id */
+        0xb200,       /* hw_dev_id (other versions 0x6f,0x73) */
+        -1,           /* hw_rev_id */
+        -1,           /* sw_dev_id */
+        "ArcusE",     /* name */
+        -1,           /* port_num */
+        DM_RETIMER    /* dev_type */
     },
     {
         DeviceSecureHost,                                      /* dm_id */
@@ -475,11 +475,11 @@ static struct device_info g_devs_info[] = {
         DM_SWITCH                                            /* dev_type */
     },
     {
-        DeviceBW00,                                      /* dm_id */
+        DeviceGB100,                                      /* dm_id */
         0x2900,                                           /* hw_dev_id */
         -1,                                               /* hw_rev_id */
         10496,                                            /* sw_dev_id */
-        "BW00",                                          /* name */
+        "GB100",                                          /* name */
         128,                                              /* port_num NEED_CHECK */
         DM_SWITCH                                         /* dev_type */
     },
@@ -561,10 +561,9 @@ static int dm_get_device_id_inner(mfile      * mf,
                                   u_int32_t  * ptr_hw_dev_id,
                                   u_int32_t  * ptr_hw_rev)
 {
-    if (mf->is_zombiefish)
-    {
+    if (mf->is_zombiefish) {
         mset_addr_space(mf,
-                        AS_CR_SPACE); // In ZombieFish mode we use recovery space, for reading device ID need cr space.
+                        AS_CR_SPACE); /* In ZombieFish mode we use recovery space, for reading device ID need cr space. */
     }
     u_int32_t dword = 0;
     int       rc;
@@ -693,7 +692,7 @@ static int dm_get_device_id_inner(mfile      * mf,
             }
         }
     } else {
-        if (mread4(mf, DEVID_ADDR, &dword) != 4) {
+        if (read_device_id(mf, &dword) != 4) {
             return CRSPACE_READ_ERROR;
         }
 
@@ -938,7 +937,7 @@ int dm_is_livefish_mode(mfile* mf)
         return 1;
     }
     dm_dev_id_t devid_t = DeviceUnknown;
-    u_int32_t   devid = 0; // hw dev ID
+    u_int32_t   devid = 0; /* hw dev ID */
     u_int32_t   revid = 0;
     int         rc = dm_get_device_id(mf, &devid_t, &devid, &revid);
 
@@ -949,6 +948,11 @@ int dm_is_livefish_mode(mfile* mf)
     u_int32_t swid = mf->dinfo->pci.dev_id;
 
     /* printf("-D- swid: %#x, devid: %#x\n", swid, devid); */
+
+    if (dm_is_gpu(devid_t)) {
+        return 0;
+    }
+
     if (dm_is_4th_gen(devid_t)) {
         return (devid == swid - 1);
     } else {
@@ -986,12 +990,7 @@ int dm_is_gr100(dm_dev_id_t type)
 
 int dm_is_gpu(dm_dev_id_t type)
 {
-    return (dm_is_gb100(type) || dm_is_gb100(type));
-}
-
-int dm_is_bw00(dm_dev_id_t type)
-{
-    return (type == DeviceBW00);
+    return (dm_is_gb100(type) || dm_is_gr100(type));
 }
 
 int dm_is_cx7(dm_dev_id_t type)
@@ -1007,14 +1006,14 @@ int dm_is_new_gen_switch(dm_dev_id_t type)
 int dm_dev_is_raven_family_switch(dm_dev_id_t type)
 {
     return (dm_dev_is_switch(type) &&
-            (type == DeviceQuantum || type == DeviceQuantum2 || type == DeviceQuantum3 || type == DeviceBW00 ||
+            (type == DeviceQuantum || type == DeviceQuantum2 || type == DeviceQuantum3 || type == DeviceGB100 || type == DeviceGR100 ||
              type == DeviceSpectrum2 || type == DeviceSpectrum3 || type == DeviceSpectrum4));
 }
 
 int dm_dev_is_ib_switch(dm_dev_id_t type)
 {
     return (dm_dev_is_switch(type) && (type == DeviceQuantum || type == DeviceQuantum2 || type == DeviceQuantum3 ||
-                                       type == DeviceBW00 || type == DeviceSwitchIB || type == DeviceSwitchIB2));
+                                       type == DeviceGB100 || type == DeviceGR100 || type == DeviceSwitchIB || type == DeviceSwitchIB2));
 }
 
 int dm_dev_is_eth_switch(dm_dev_id_t type)
