@@ -3,6 +3,7 @@
  * flint_params.h - FLash INTerface
  *
  * Copyright (c) 2013 Mellanox Technologies Ltd.  All rights reserved.
+ * Copyright (c) 2021 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
  *
  * This software is available to you under a choice of one of two
  * licenses.  You may choose to be licensed under the terms of the GNU
@@ -46,7 +47,8 @@
 
 using namespace std;
 
-typedef enum {
+typedef enum
+{
     SC_No_Cmd = 0,
     SC_Burn,
     SC_Query,
@@ -60,6 +62,7 @@ typedef enum {
     SC_Sg,
     SC_Smg,
     SC_Set_Vpd,
+    SC_Set_Cert_Chain,
     SC_Sv,
     SC_Ri,
     SC_Dc,
@@ -88,15 +91,14 @@ typedef enum {
     SC_Image_Reactivation,
     SC_RSA_Sign,
     SC_Binary_Compare,
-    SC_Import_Hsm_Key,
-#if !defined(UEFI_BUILD) && !defined(NO_OPEN_SSL)
-    SC_Export_Public_Key
-#endif
+    SC_Export_Public_Key,
+    SC_Query_Components
 } sub_cmd_t;
 
-class FlintParams {
+class FlintParams
+{
 public:
-    //add more params
+    // add more params
     FlintParams();
     ~FlintParams();
     bool device_specified;
@@ -119,8 +121,10 @@ public:
     bool next_boot_fw_ver;
     bool skip_rom_query;
     bool image_specified;
+    bool nonencrypted_image_specified;
     bool mfa2_specified;
     string image;
+    string nonencrypted_image;
     bool nofs;
     bool allow_psid_change;
     bool allow_rom_change;
@@ -149,14 +153,13 @@ public:
     vector<string> cmd_params;
     string fullCmd;
     bool use_dev_img_info;
+    bool ignore_crc_check;
+    bool hexdump_format;
     bool skip_ci_req;
     bool use_dev_rom;
-    bool privkey_specified;
-    bool pubkey_specified;
     string privkey_file;
     string pubkey_file;
 
-    bool uuid_specified;
     string privkey_uuid;
     bool privkey2_specified;
     bool key_specified;
@@ -174,17 +177,12 @@ public:
     string congestion_control_param;
     bool use_cpu_utilization;
     int cpu_percent;
-    bool hsm_specified;
-    string private_key_label;
-    string public_key_label;
-    bool private_key_label_specified;
-    bool public_key_label_specified;
     bool output_file_specified;
     string output_file;
     bool hsm_password_specified;
     string hsm_password;
     bool linkx_control;
-    int  cableDeviceIndex;
+    int cableDeviceIndex;
     int cableDeviceSize;
     bool cable_device_index_specified;
     bool cable_device_size_specified;
@@ -192,12 +190,13 @@ public:
     bool activate;
     bool download_downstream_specified;
     bool downstream_device_ids_specified;
-    std::vector<int>  downstream_device_ids;
+    std::vector<int> downstream_device_ids;
     bool download_transfer;
     u_int8_t activate_delay_sec;
-    string openssl_engine;
-    string openssl_key_id;
-    bool openssl_engine_usage_specified;
+    u_int32_t cert_chain_index;
+    string component_type;
+    bool imageSizeOnly;
+    string cert_uuid;
 };
 
 #endif
