@@ -323,6 +323,9 @@ public:
     FlintStatus executeCommand() override;
     bool verifyParams() override;
     FlintStatus querySyncE();
+    FlintStatus QueryCertStatus();
+private:
+    FwComponent::comps_ids_t _comp;
 };
 
 class Extract4MBImageSubCommand : public SubCommand
@@ -586,6 +589,7 @@ class HwSubCommand : public SubCommand
 {
 private:
     FlintStatus printAttr(const ext_flash_attr_t& attr);
+    bool PrintWriteProtectedBits(const ext_flash_attr_t& attr);
 
 public:
     HwSubCommand();
