@@ -40,14 +40,13 @@
 #include <stdarg.h>
 #include <stdio.h>
 
-//#define NDEBUG //uncomment in order to enable asserts
+// #define NDEBUG //uncomment in order to disable asserts
 #include <assert.h>
 
 #include <ext_libs/sqlite/sqlite3.h>
 #include "mlxcfg_db_manager.h"
 #include "mlxcfg_utils.h"
 #include <memory>
-
 // clang-format off
 #define SQL_SELECT_ALL_TLVS \
     "SELECT * FROM tlvs"
@@ -258,7 +257,8 @@ void MlxcfgDBManager::getAllTLVs()
     while (j < fetchedTLVs.size() && i < fetchedParams.size())
     {
         std::shared_ptr<Param> p = fetchedParams[i];
-        if (p->_tlvName == fetchedTLVs[j]->_name)
+        if (p->_tlvName == fetchedTLVs[j]->_name && p->_port == fetchedTLVs[j]->_port &&
+            p->_module == fetchedTLVs[j]->_module)
         {
             fetchedTLVs[j]->_params.push_back(p);
             i++; // move to next parameter
@@ -417,6 +417,19 @@ TLVConf* MlxcfgDBManager::getAndCreateTLVByName(string tlvName, u_int32_t port,
     return tlv;
 }
 
+TLVConf* MlxcfgDBManager::getTLVByNameOnlyAux(string tlv_name)
+{
+    VECTOR_ITERATOR(TLVConf*, fetchedTLVs, it)
+    {
+        TLVConf* t = *it;
+        if (t->_name == tlv_name)
+        {
+            return t;
+        }
+    }
+    return NULL;
+}
+
 TLVConf* MlxcfgDBManager::getTLVByName(string tlvName, u_int32_t port, int32_t module)
 {
     TLVConf* tlv = NULL;
@@ -430,6 +443,29 @@ TLVConf* MlxcfgDBManager::getTLVByName(string tlvName, u_int32_t port, int32_t m
     return tlv;
 }
 
+TLVConf* MlxcfgDBManager::getDependencyTLVByName(string tlvName, u_int32_t cTLVPort, int32_t cTLVModule)
+{
+    TLVConf* dependendTLV = getTLVByNameOnlyAux(tlvName);
+    if (!dependendTLV)
+    {
+        getAllTLVs();
+        dependendTLV = getTLVByNameOnlyAux(tlvName);
+        if (!dependendTLV)
+        {
+            // TLV not in DB
+            return NULL;
+        }
+    }
+    if ((dependendTLV->_tlvClass == TLVClass::Physical_Port) || (dependendTLV->_tlvClass == TLVClass::Module))
+    {
+        return getTLVByName(tlvName, cTLVPort, cTLVModule); // get TLV with same port and module as the requester TLV
+    }
+    else // this is not port / module related tlv, ignore the requeter port/module (for cross class dependency)
+    {
+        return getTLVByName(tlvName, 0, -1);
+    }
+}
+
 TLVConf* MlxcfgDBManager::getTLVByIndexAndClassAux(u_int32_t id, TLVClass c)
 {
     VECTOR_ITERATOR(TLVConf*, fetchedTLVs, it)
@@ -501,20 +537,22 @@ tuple<string, int> MlxcfgDBManager::splitMlxcfgNameAndPortOrModule(std::string m
 }
 
 TLVConf* MlxcfgDBManager::findTLVInExisting(std::string mlxconfigName,
-                                            std::string noPortMlxcfgName,
-                                            std::string noModuleMlxcfgName,
+                                            std::string noPortModuleMlxcfgName,
                                             u_int32_t port,
                                             u_int32_t index,
                                             int32_t module)
 {
     VECTOR_ITERATOR(TLVConf*, fetchedTLVs, it)
     {
-        if ((port != 0 && (*it)->findParamByMlxconfigNamePortModule(noPortMlxcfgName, port, module)) ||
-            (module != -1 && (*it)->findParamByMlxconfigNamePortModule(noModuleMlxcfgName, port, module)) ||
+        if (((port != 0 || module != -1) &&
+             (*it)->findParamByMlxconfigNamePortModule(noPortModuleMlxcfgName, port, module)) ||
             (*it)->findParamByMlxconfigNamePortModule(mlxconfigName, port, module) ||
             (*it)->findParamByMlxconfigNamePortModule(mlxconfigName + getArraySuffixByInterval(index), port, module))
         {
-            return (*it);
+            if (port == (*it)->_port && module == (*it)->_module)
+            {
+                return (*it);
+            }
         }
     }
     return NULL;
@@ -548,26 +586,12 @@ void MlxcfgDBManager::findTLVInDB(string mlxconfigName, u_int32_t index)
     }
 }
 
-TLVConf* MlxcfgDBManager::getTLVByParamMlxconfigName(std::string mlxconfigName, u_int32_t index, mfile* mf)
+tuple<string, int, int> MlxcfgDBManager::getMlxconfigNamePortModule(string mlxconfigName, mfile* mf)
 {
     u_int32_t port = 0;
     int32_t module = -1;
-    string tlvName = "";
     auto namePortTuple = splitMlxcfgNameAndPortOrModule(mlxconfigName, PORT, mf);
     auto nameModuleTuple = splitMlxcfgNameAndPortOrModule(mlxconfigName, MODULE, mf);
-
-    TLVConf* existingTlv = findTLVInExisting(mlxconfigName,
-                                             get<0>(namePortTuple),
-                                             get<0>(nameModuleTuple),
-                                             get<1>(namePortTuple),
-                                             index,
-                                             get<1>(nameModuleTuple));
-    if (existingTlv != NULL && int(existingTlv->_port) == get<1>(namePortTuple) &&
-        existingTlv->_module == get<1>(nameModuleTuple))
-    {
-        return existingTlv;
-    }
-
     if (get<1>(namePortTuple) != 0)
     {
         port = get<1>(namePortTuple);
@@ -579,6 +603,23 @@ TLVConf* MlxcfgDBManager::getTLVByParamMlxconfigName(std::string mlxconfigName,
         mlxconfigName = get<0>(nameModuleTuple);
     }
 
+    return make_tuple(mlxconfigName, port, module);
+}
+
+TLVConf* MlxcfgDBManager::getTLVByParamMlxconfigName(std::string mlxconfigName, u_int32_t index, mfile* mf)
+{
+    string tlvName = "";
+
+    auto ret = this->getMlxconfigNamePortModule(mlxconfigName, mf);
+    string mlxconfigNameNoPortModuleName = get<0>(ret);
+    u_int32_t port = get<1>(ret);
+    int32_t module = get<2>(ret);
+    TLVConf* existingTlv = findTLVInExisting(mlxconfigName, mlxconfigNameNoPortModuleName, port, index, module);
+    if (existingTlv != NULL && existingTlv->_port == port && existingTlv->_module == module)
+    {
+        return existingTlv;
+    }
+    mlxconfigName = mlxconfigNameNoPortModuleName;
     findTLVInDB(mlxconfigName, index);
 
     tlvName = _paramSqlResult->_tlvName;
