@@ -48,9 +48,6 @@
 #if !defined(NO_OPEN_SSL)
 #include <mlxsign_lib/mlxsign_lib.h>
 #include <mlxsign_lib/mlxsign_signer_interface.h>
-#if !defined(NO_DYNAMIC_ENGINE)
-#include <mlxsign_lib/mlxsign_openssl_engine.h>
-#endif
 #endif
 #include "mlxcfg_expression.h"
 #include "mlxcfg_generic_commander.h"
@@ -515,7 +512,7 @@ bool GenericCommander::checkDependency(TLVConf* cTLV, string dStr)
     if (dStr.empty())
     {
         dm_dev_id_t deviceId = DeviceUnknown;
-        u_int32_t hwDevId, hwRevId;
+        u_int32_t hwDevId = 0, hwRevId = 0;
         if (dm_get_device_id(_mf, &deviceId, &hwDevId, &hwRevId))
         {
             throw MlxcfgException("Failed to identify the device");
@@ -929,7 +926,7 @@ const char* GenericCommander::loadConfigurationGetStr()
 {
     int rc;
     dm_dev_id_t deviceId = DeviceUnknown;
-    u_int32_t hwDevId, hwRevId;
+    u_int32_t hwDevId = 0, hwRevId = 0;
     struct reg_access_hca_mfrl_reg_ext mfrl;
 
     if (dm_get_device_id(_mf, &deviceId, &hwDevId, &hwRevId))
@@ -1258,8 +1255,8 @@ void GenericCommander::XML2TLVConf(const string& xmlContent, vector<TLVConf*>& t
         while (currTlv)
         {
             IGNORE_UNUSEFUL_NODE(currTlv)
-            u_int32_t port;
-            u_int32_t u_module;
+            u_int32_t port = 0;
+            u_int32_t u_module = 0;
             int32_t module;
             TLVConf* tlvConf = nullptr;
             bool isAllPorts = false;
@@ -1533,12 +1530,10 @@ void GenericCommander::XML2Bin(const string& xml, vector<u_int32_t>& buff, bool
 
 void GenericCommander::sign(vector<u_int32_t>& buff,
                             const string& privateKeyFile,
-                            const string& keyPairUUid,
-                            const string& openssl_engine,
-                            const string& openssl_key_identifier)
+                            const string& keyPairUUid)
 {
     (void)keyPairUUid;
-#if !defined(UEFI_BUILD) && !defined(NO_OPEN_SSL) && !defined(NO_DYNAMIC_ENGINE)
+#if !defined(UEFI_BUILD) && !defined(NO_OPEN_SSL)
     vector<u_int32_t> encDigestDW;
     vector<u_int8_t> digest, encDigest, bytesBuff;
     MlxSign::SHAType shaType;
@@ -1546,7 +1541,7 @@ void GenericCommander::sign(vector<u_int32_t>& buff,
 
     copyDwVectorToBytesVector(buff, bytesBuff);
 
-    if (openssl_key_identifier.empty() && privateKeyFile.empty())
+    if (privateKeyFile.empty())
     {
         shaType = MlxSign::SHA256;
         MlxSignSHA256 mlxSignSHA;
@@ -1555,22 +1550,8 @@ void GenericCommander::sign(vector<u_int32_t>& buff,
         encDigest.insert(encDigest.begin(), digest.begin(), digest.end());
     }
     else
-    {
-        if (!openssl_key_identifier.empty())
-        {
-            // Sign with local HSM engine
-            shaType = MlxSign::SHA512;
-#if !defined(NO_DYNAMIC_ENGINE)
-            signer = unique_ptr<MlxSign::Signer>(new MlxSign::MlxSignRSAViaHSM(openssl_engine, openssl_key_identifier));
-#else
-            reportErr(true, "Open SSL functionality is not supported.\n");
-#endif
-        }
-        else
-        {
-            signer = unique_ptr<MlxSign::Signer>(new MlxSign::MlxSignRSAViaOpenssl(privateKeyFile));
-        }
-
+    {       
+        signer = unique_ptr<MlxSign::Signer>(new MlxSign::MlxSignRSAViaOpenssl(privateKeyFile));
         if (signer != nullptr && signer->Init() != MlxSign::MLX_SIGN_SUCCESS)
         {
             signer.reset();
@@ -1656,8 +1637,6 @@ void GenericCommander::sign(vector<u_int32_t>& buff,
 #else
     (void)buff;
     (void)privateKeyFile;
-    (void)openssl_engine;
-    (void)openssl_key_identifier;
     throw MlxcfgException("Sign command is not implemented\n");
 #endif
 }
@@ -1791,14 +1770,15 @@ void GenericCommander::orderConfTlvs(vector<TLVConf*>& tlvs)
     }
 
     // file_applicable_to must be after the component
+    uint32_t deltaLocation = 1;
     VECTOR_ITERATOR(TLVConf*, tlvs, it)
     {
         TLVConf* tlv = *it;
         if (tlv->_name == "file_applicable_to" || tlv->_name == "file_device_id")
         {
-            *it = *(tlvs.begin() + 1);
-            *(tlvs.begin() + 1) = tlv;
-            break;
+            *it = *(tlvs.begin() + deltaLocation);
+            *(tlvs.begin() + deltaLocation) = tlv;
+            deltaLocation++;
         }
     }
 }
@@ -1995,9 +1975,9 @@ int RawCfgParams5thGen::setOnDev(mfile* mf, RawTlvMode mode)
 {
     int rc;
     mft_signal_set_handling(1);
-    DEBUG_PRINT_SEND(&_nvdaTlv, nvda);
+    DEBUG_PRINT_SEND(&_nvdaTlv, mnvda);
     rc = reg_access_mnvda(mf, mode == SET_RAW ? REG_ACCESS_METHOD_SET : REG_ACCESS_METHOD_GET, &_nvdaTlv);
-    DEBUG_PRINT_RECEIVE(&_nvdaTlv, nvda);
+    DEBUG_PRINT_RECEIVE(&_nvdaTlv, mnvda);
     dealWithSignal();
     if (rc)
     {
