@@ -107,9 +107,7 @@ public:
     void createConf(const string& xml, vector<u_int32_t>& buff);
     void sign(vector<u_int32_t>& buff,
               const string& privateKeyFile = "",
-              const string& keyPairUUid = "",
-              const string& openssl_engine = "",
-              const string& openssl_key_identifier = "");
+              const string& keyPairUUid = "");
     void apply(const vector<u_int8_t>& buff);
 };
 
