@@ -38,6 +38,7 @@
 #include <algorithm>
 #include <errno.h>
 #include <utility>
+#include <fstream>
 
 #include <common/tools_version.h>
 
@@ -88,12 +89,14 @@ void MlxCfg::printHelp()
     printFlagLine("h", "help", "", "Display help message.");
     printFlagLine("v", "version", "", "Display version info.");
     printFlagLine("e", "enable_verbosity", "", "Show default and current configurations.");
+    printFlagLine("j", "json_format", "file",
+                  "Save the query output to file in JSON format, only usable with Query command");
     printFlagLine("y", "yes", "", "Answer yes in prompt.");
     printFlagLine("a", "all_attrs", "", "Show all attributes in the XML template");
     printFlagLine("p", "private_key", "PKEY", "pem file for private key");
     printFlagLine("u", "key_uuid", "UUID", "keypair uuid");
-    printFlagLine("eng", "openssl_engine", "ENGINE NAME", "OpenSSL engine name");
-    printFlagLine("k", "openssl_key_id", "IDENTIFIER", "OpenSSL key identifier");
+    printFlagLine("eng", "openssl_engine", "ENGINE NAME", "deprecated");
+    printFlagLine("k", "openssl_key_id", "IDENTIFIER", "deprecated");
     printFlagLine("t", "device_type", "switch/hca", "Specify the device type");
 
     // print commands
@@ -137,6 +140,9 @@ void MlxCfg::printHelp()
     printf("\n");
     printf(IDENT "Examples:\n");
     printf(IDENT2 "%-35s: %s\n", "To query configurations", MLXCFG_NAME " -d " MST_DEV_EXAMPLE " query");
+    printf(IDENT2 "%-35s: %s\n", "To query in json format",
+           MLXCFG_NAME " -d " MST_DEV_EXAMPLE " -j /tmp/query.json query");
+    printf(IDENT2 "%-35s: %s\n", "To query specific parameter", MLXCFG_NAME " -d " MST_DEV_EXAMPLE " q NUM_OF_VFS");
     printf(IDENT2 "%-35s: %s\n", "To set configuration",
            MLXCFG_NAME " -d " MST_DEV_EXAMPLE " set SRIOV_EN=1 NUM_OF_VFS=16 WOL_MAGIC_EN_P1=1");
     printf(IDENT2 "%-35s: %s\n", "To set raw configuration",
@@ -440,6 +446,15 @@ mlxCfgStatus MlxCfg::parseArgs(int argc, char* argv[])
             }
             _mlxParams.dbName = argv[i];
         }
+        else if (arg == "-j" || arg == "--json_format")
+        {
+            if (++i == argc)
+            {
+                return err(true, "missing .json output file");
+            }
+            _mlxParams.isJsonOutputRequested = true;
+            _mlxParams.NVOutputFile = argv[i];
+        }
         else if (arg == "-y" || arg == "--yes")
         {
             _mlxParams.yes = true;
@@ -478,19 +493,11 @@ mlxCfgStatus MlxCfg::parseArgs(int argc, char* argv[])
         }
         else if (arg == "-eng" || arg == "--openssl_engine")
         {
-            if (++i == argc)
-            {
-                return err(true, "missing OpenSSL engine");
-            }
-            _mlxParams.opensslEngine = argv[i];
+            return err(true, "The '--openssl_engine' and '-eng' flags have been deprecated.\n");
         }
         else if (arg == "-k" || arg == "--openssl_key_id")
         {
-            if (++i == argc)
-            {
-                return err(true, "missing OpenSSL key identifier");
-            }
-            _mlxParams.opensslKeyId = argv[i];
+            return err(true, "The '--openssl_key_id' and '-k' flags have been deprecated.\n");
         }
         // hidden flag --force used to ignore parameter checks
         else if (arg == "--force")
@@ -588,6 +595,11 @@ mlxCfgStatus MlxCfg::parseArgs(int argc, char* argv[])
         return err(true, "missing configuration arguments. For more information please run " MLXCFG_NAME " -h|--help.");
     }
 
+    if ((_mlxParams.cmd != Mc_Query) && _mlxParams.isJsonOutputRequested)
+    {
+        return err(true, "Json format is only supported for query command.");
+    }
+
     if ((_mlxParams.cmd == Mc_Set || _mlxParams.cmd == Mc_Clr_Sem || _mlxParams.cmd == Mc_Set_Raw ||
          _mlxParams.cmd == Mc_Get_Raw || _mlxParams.cmd == Mc_Backup || _mlxParams.cmd == Mc_ShowConfs || 
 		 _mlxParams.cmd == Mc_Apply) &&
@@ -637,15 +649,7 @@ mlxCfgStatus MlxCfg::parseArgs(int argc, char* argv[])
 
     if (_mlxParams.cmd == Mc_CreateConf)
     {
-        if (!_mlxParams.privPemFile.empty() && (!_mlxParams.opensslEngine.empty() || !_mlxParams.opensslKeyId.empty()))
-        {
-            return err(true,
-                       "Please provide either private pem file or OpenSSL engine and key identifier "
-                       "but not both of them");
-        }
-
-        if (!_mlxParams.keyPairUUID.empty() ^ (!_mlxParams.privPemFile.empty() ||
-                                               (!_mlxParams.opensslEngine.empty() && !_mlxParams.opensslKeyId.empty())))
+        if (!_mlxParams.keyPairUUID.empty() ^ (!_mlxParams.privPemFile.empty()))
         {
             return err(true,
                        "if you want to sign the configuration file you have to "
