@@ -42,6 +42,9 @@
 #include <sstream>
 #include <errno.h>
 #include <time.h>
+#include <memory>
+#include <stdexcept>
+#include <system_error>
 
 #include <tools_dev_types.h>
 #include <reg_access/reg_access.h>
@@ -235,6 +238,22 @@ bool MlxCfg::askUser(const char* question, bool add_prefix, bool add_suffix)
 mlxCfgStatus MlxCfg::queryDevsCfg()
 {
     bool shouldFail = false;
+    if (_mlxParams.isJsonOutputRequested)
+    {
+        // create/clear json file
+        ofstream jsonOutStream(_mlxParams.NVOutputFile);
+        if (jsonOutStream)
+        {
+            jsonOutStream << "{}" << endl;
+            jsonOutStream.close(); // file is good and clear, we can continue to use it later on
+        }
+        else
+        {
+            cerr << "Failed to open \"" << _mlxParams.NVOutputFile << "\""
+                 << ". Reason: " << std::error_code{errno, std::generic_category()}.message() << endl;
+            return MLX_CFG_ERROR;
+        }
+    }
     if (_mlxParams.device.length())
     {
         if (queryDevCfg(_mlxParams.device.c_str()))
@@ -279,6 +298,18 @@ mlxCfgStatus MlxCfg::queryDevsCfg()
         }
         mdevices_info_destroy(dev, numOfDev);
     }
+    if (_mlxParams.isJsonOutputRequested)
+    {
+        if (shouldFail)
+        {
+            cout << "Query output saved to " << _mlxParams.NVOutputFile << " but one or more devices had an error."
+                 << endl;
+        }
+        else
+        {
+            cout << "Query output saved to " << _mlxParams.NVOutputFile << " successfully" << endl;
+        }
+    }
     return shouldFail ? MLX_CFG_ERROR : MLX_CFG_OK;
 }
 
@@ -312,6 +343,58 @@ int MlxCfg::printParam(string param, u_int32_t val)
         printf(" ");                 \
     }
 
+void MlxCfg::writeParamToJson(Json::Value& oJsonValue, string field, string param, u_int32_t val)
+{
+    if (val == MLXCFG_UNKNOWN)
+    {
+        oJsonValue[field] = "N/A";
+        return;
+    }
+
+    string s = numToStr(val);
+    u_int32_t n = 0;
+    if (param == "" || param == s || (strToNum(param, n, 10) && n == val))
+    {
+        oJsonValue[field] = val;
+        return;
+    }
+    if (param.find("Array") == string::npos)
+    {
+        param += "(" + s + ")";
+    }
+    oJsonValue[field] = param;
+}
+
+mlxCfgStatus
+  MlxCfg::WriteSingleParam(QueryOutputItem& queryOutItem, string deviceIndex, u_int8_t verbose, Json::Value& oJsonValue)
+{
+    bool showDefault = QUERY_DEFAULT_MASK & verbose;
+    bool showCurrent = QUERY_CURRENT_MASK & verbose;
+    bool modified = ((showDefault && queryOutItem.nextVal != queryOutItem.defVal) ||
+                     (showCurrent && queryOutItem.nextVal != queryOutItem.currVal));
+
+    oJsonValue[deviceIndex]["tlv_configuration"][queryOutItem.mlxconfigName] = {};
+    oJsonValue[deviceIndex]["tlv_configuration"][queryOutItem.mlxconfigName]["read_only"] = queryOutItem.isReadOnly;
+    writeParamToJson(oJsonValue[deviceIndex]["tlv_configuration"][queryOutItem.mlxconfigName], "next_value",
+                     queryOutItem.strNextVal, queryOutItem.nextVal);
+
+    if (showDefault || showCurrent)
+    {
+        oJsonValue[deviceIndex]["tlv_configuration"][queryOutItem.mlxconfigName]["modified"] = modified;
+    }
+    if (showDefault)
+    {
+        writeParamToJson(oJsonValue[deviceIndex]["tlv_configuration"][queryOutItem.mlxconfigName], "default_value",
+                         queryOutItem.strDefVal, queryOutItem.defVal);
+    }
+    if (showCurrent)
+    {
+        writeParamToJson(oJsonValue[deviceIndex]["tlv_configuration"][queryOutItem.mlxconfigName], "current_value",
+                         queryOutItem.strCurrVal, queryOutItem.currVal);
+    }
+    return MLX_CFG_OK;
+}
+
 void MlxCfg::printSingleParam(const char* name, QueryOutputItem& queryOutItem, u_int8_t verbose, bool printNewCfg)
 {
     bool showDefault = QUERY_DEFAULT_MASK & verbose;
@@ -373,65 +456,75 @@ const char* MlxCfg::getDeviceName(mfile* mf)
     return dm_dev_type2str(_devType);
 }
 
-void MlxCfg::printOpening(mfile* mf, const char* dev, int devIndex)
+void MlxCfg::printOpening(mfile* mf, const char* dev, string deviceIndex, Json::Value& oJsonValue)
 {
-    printf("\nDevice #%d:\n", devIndex);
-    printf("----------\n\n");
     const char* devType = getDeviceName(mf);
-    printf("%-20s%-20s\n", "Device type:", devType);
-    if (!dm_is_4th_gen(_devType))
+    string deviceNameInfo = "N/A";
+    string deviceDescriptionInfo = "N/A";
+    std::vector<char> info;
+    info.reserve(16);
+    if (getDeviceInformationString(mf, Device_Name, info))
     {
-        std::vector<char> info;
-        info.reserve(16);
-        if (!getDeviceInformationString(mf, Device_Name, info))
-        {
-            printf("%-20s%-20s\n", "Name:", "N/A");
-        }
-        else
-        {
-            printf("%-20s%-20s\n", "Name:", info.data());
-        }
-        info.clear();
-        if (!getDeviceInformationString(mf, Device_Description, info))
-        {
-            printf("%-20s%-20s\n", "Description:", "N/A");
-        }
-        else
-        {
-            printf("%-20s%-20s\n", "Description:", info.data());
-        }
+        deviceNameInfo = info.data();
+    }
+    info.clear();
+    if (getDeviceInformationString(mf, Device_Description, info))
+    {
+        deviceDescriptionInfo = info.data();
+    }
+
+    if (_mlxParams.isJsonOutputRequested)
+    {
+        oJsonValue[deviceIndex] = {};
+        oJsonValue[deviceIndex]["device_type"] = devType;
+        oJsonValue[deviceIndex]["name"] = deviceNameInfo;
+        oJsonValue[deviceIndex]["description"] = deviceDescriptionInfo;
+        oJsonValue[deviceIndex]["device"] = dev;
+        oJsonValue[deviceIndex]["tlv_configuration"] = {};
+    }
+    else
+    {
+        printf("\n%s:\n", deviceIndex.c_str());
+        printf("----------\n\n");
+        printf("%-20s%-20s\n", "Device type:", devType);
+        printf("%-20s%-20s\n", "Name:", deviceNameInfo.c_str());
+        printf("%-20s%-20s\n", "Description:", deviceDescriptionInfo.c_str());
+        printf("%-20s%-20s\n", "Device:", dev);
+        printf("\n");
     }
-    printf("%-20s%-20s\n", "Device:", dev);
 }
 
 void MlxCfg::printConfHeader(bool showDefualt, bool showNew, bool showCurrent)
 {
-    // print configuration Header
-    if (showDefualt)
+    if (!_mlxParams.isJsonOutputRequested)
     {
-        if (showCurrent)
+        // print configuration Header
+        if (showDefualt)
         {
-            printf("%-20s%39s%21s%23s", "Configurations:", "Default", "Current", NEXT_STR);
+            if (showCurrent)
+            {
+                printf("%-20s%44s%20s%18s", "Configurations:", "Default", "Current", NEXT_STR);
+            }
+            else
+            {
+                printf("%-20s%44s%18s", "Configurations:", "Default", NEXT_STR);
+            }
         }
         else
         {
-            printf("%-20s%39s%23s", "Configurations:", "Default", NEXT_STR);
+            if (showCurrent)
+            {
+                printf("%-20s%46s%18s", "Configurations:", "Current", NEXT_STR);
+            }
+            else
+            {
+                printf("%-20s%46s", "Configurations:", NEXT_STR);
+            }
         }
-    }
-    else
-    {
-        if (showCurrent)
+        if (showNew)
         {
-            printf("%-20s%41s%18s", "Configurations:", "Current", NEXT_STR);
+            printf("       %s", "New");
         }
-        else
-        {
-            printf("%-20s%41s", "Configurations:", NEXT_STR);
-        }
-    }
-    if (showNew)
-    {
-        printf("       %s", "New");
     }
 }
 
@@ -591,8 +684,23 @@ mlxCfgStatus MlxCfg::queryDevCfg(Commander* commander,
     bool defaultSupported = false, currentSupported = false;
     bool showDefault = false, showCurrent = false;
 
-    printOpening(commander->mf(), dev, devIndex);
-    printf("\n");
+    Json::Value oJsonValue;
+    if (_mlxParams.isJsonOutputRequested)
+    {
+        ifstream jsonInputStream(_mlxParams.NVOutputFile);
+        mstflint::common::ReaderWrapper readerWrapper;
+        Json::Reader* reader = readerWrapper.getReader();
+        bool rc = reader->parse(jsonInputStream, oJsonValue);
+        jsonInputStream.close();
+        if (!rc)
+        {
+            cerr << "failed to read json file [" << _mlxParams.NVOutputFile << "]" << endl;
+            return MLX_CFG_ERROR;
+        }
+    }
+
+    string deviceIndex = "Device #" + std::to_string(devIndex);
+    printOpening(commander->mf(), dev, deviceIndex, oJsonValue);
 
     vector<string> defaultFailedTLVs, currentFailedTLVs, nextFailedTLVs;
 
@@ -653,16 +761,26 @@ mlxCfgStatus MlxCfg::queryDevCfg(Commander* commander,
 
     removeContinuanceArray(newoutput, output);
 
-    // print output table:
-    VECTOR_ITERATOR(QueryOutputItem, newoutput, o)
+    uint8_t verbosity =
+      QUERY_NEXT_MASK | (showDefault ? QUERY_DEFAULT_MASK : 0) | (showCurrent ? QUERY_CURRENT_MASK : 0);
+
+    if (_mlxParams.isJsonOutputRequested)
     {
-        printSingleParam(
-          o->mlxconfigName.c_str(),
-          *o,
-          QUERY_NEXT_MASK | (showDefault ? QUERY_DEFAULT_MASK : 0) | (showCurrent ? QUERY_CURRENT_MASK : 0),
-          printNewCfg);
-        isParamsDiffer |= (showDefault && (o->nextVal != o->defVal)) || (showCurrent && (o->nextVal != o->currVal));
-        isParamsReadOnly |= o->isReadOnly;
+        // write output table to json file:
+        VECTOR_ITERATOR(QueryOutputItem, newoutput, o)
+        {
+            WriteSingleParam(*o, deviceIndex, verbosity, oJsonValue);
+        }
+    }
+    else
+    {
+        // print output table:
+        VECTOR_ITERATOR(QueryOutputItem, newoutput, o)
+        {
+            printSingleParam(o->mlxconfigName.c_str(), *o, verbosity, printNewCfg);
+            isParamsDiffer |= (showDefault && (o->nextVal != o->defVal)) || (showCurrent && (o->nextVal != o->currVal));
+            isParamsReadOnly |= o->isReadOnly;
+        }
     }
 
     string failedTLVsErrorMessage = "Failed to query some of the TLVs:\n";
@@ -670,14 +788,17 @@ mlxCfgStatus MlxCfg::queryDevCfg(Commander* commander,
     failedTLVsErrorMessage += checkFailedTLVsVector(currentFailedTLVs, "current");
     failedTLVsErrorMessage += checkFailedTLVsVector(nextFailedTLVs, "next");
 
-    if (isParamsDiffer)
+    if (!_mlxParams.isJsonOutputRequested)
     {
-        printf("The '*' shows parameters with next value different "
-               "from default/current value.\n");
-    }
-    if (isParamsReadOnly)
-    {
-        printf("\nThe 'RO' shows parameters which are for read only and cannot be changed\n");
+        if (isParamsDiffer)
+        {
+            printf("The '*' shows parameters with next value different "
+                   "from default/current value.\n");
+        }
+        if (isParamsReadOnly)
+        {
+            printf("\nThe 'RO' shows parameters which are for read only and cannot be changed\n");
+        }
     }
 
     if (_mlxParams.enableVerbosity)
@@ -696,6 +817,16 @@ mlxCfgStatus MlxCfg::queryDevCfg(Commander* commander,
         }
     }
 
+    if (_mlxParams.isJsonOutputRequested)
+    {
+        ofstream jsonOutputStream(_mlxParams.NVOutputFile);
+        Json::StreamWriterBuilder jsonWriter;
+        std::string oJsonString = Json::writeString(jsonWriter, oJsonValue);
+        jsonOutputStream << oJsonString;
+        jsonOutputStream << endl;
+        jsonOutputStream.close();
+    }
+
     if (params.size() == 0)
     {
         err(false, "Device doesn't support any configuration changes.");
@@ -1116,7 +1247,7 @@ mlxCfgStatus MlxCfg::resetDevCfg(const char* dev)
         commander = Commander::create(dev, _mlxParams.dbName);
         if (_mlxParams.setParams.size() == 0)
         {
-        commander->invalidateCfgs();
+            commander->invalidateCfgs();
         }
         else
         {
@@ -1497,7 +1628,7 @@ mlxCfgStatus MlxCfg::createConf()
     return MLX_CFG_ERROR_EXIT;
 #else
     string xml;
-    vector < u_int32_t > buff;
+    vector<u_int32_t> buff;
     mlxCfgStatus rc = MLX_CFG_OK;
 
     rc = readNVInputFile(xml);
@@ -1508,16 +1639,16 @@ mlxCfgStatus MlxCfg::createConf()
         GenericCommander commander(NULL, _mlxParams.dbName, _mlxParams.deviceType);
         commander.createConf(xml, buff);
 
-        if (!_mlxParams.privPemFile.empty() && !_mlxParams.keyPairUUID.empty()) {
-            commander.sign(buff, _mlxParams.privPemFile, _mlxParams.keyPairUUID, "", "");
-        } else if (!_mlxParams.opensslEngine.empty() && !_mlxParams.opensslKeyId.empty() &&
-                   !_mlxParams.keyPairUUID.empty()) {
-            commander.sign(buff, "", _mlxParams.keyPairUUID, _mlxParams.opensslEngine, _mlxParams.opensslKeyId);
-        } else {
+        if (!_mlxParams.privPemFile.empty() && !_mlxParams.keyPairUUID.empty())
+        {
+            commander.sign(buff, _mlxParams.privPemFile, _mlxParams.keyPairUUID);
+        }
+        else
+        {
             commander.sign(buff);
         }
     }
-    catch(MlxcfgException & e)
+    catch (MlxcfgException& e)
     {
         printf("-E- %s\n", e._err.c_str());
         rc = MLX_CFG_ERROR;
