@@ -39,6 +39,9 @@
 
 #include <compatibility.h>
 #include <mtcr.h>
+#include <json/reader.h>
+#include <json/writer.h>
+#include "common/tools_json.h"
 
 #ifdef CABLES_SUPP
 #include <cable_access/cdb_cable_commander.h>
@@ -111,10 +114,9 @@ public:
         dbName(DB_NAME),
         privPemFile(),
         keyPairUUID(),
-        opensslEngine(),
-        opensslKeyId(),
         allAttrs(false),
         cmd(Mc_UnknownCmd),
+        isJsonOutputRequested(false),
         yes(false),
         force(false),
         enableVerbosity(false)
@@ -131,10 +133,9 @@ public:
     std::string dbName;
     std::string privPemFile;
     std::string keyPairUUID;
-    std::string opensslEngine;
-    std::string opensslKeyId;
     bool allAttrs;
     mlxCfgCmd cmd;
+    bool isJsonOutputRequested;
     bool yes;
     std::vector<ParamView> setParams;
     bool force; // ignore parameter checks
@@ -155,7 +156,7 @@ private:
     const char* getDeviceName(mfile* mf);
     void printVersion();
     void printUsage();
-    void printOpening(mfile* mf, const char* dev, int devIndex);
+    void printOpening(mfile* mf, const char* dev, string deviceIndex, Json::Value& oJsonValue);
     void printConfHeader(bool showDefualt, bool showNew, bool showCurrent);
     mlxCfgStatus getNumberFromString(const char* str, u_int32_t& num);
     mlxCfgStatus parseArgs(int argc, char* argv[]);
@@ -206,6 +207,11 @@ private:
     mlxCfgStatus writeNVOutputFile(string content);
     mlxCfgStatus writeNVOutputFile(vector<string> lines);
 
+    // write query output to json funtions
+    mlxCfgStatus
+      WriteSingleParam(QueryOutputItem& queryOutItem, string deviceIndex, u_int8_t verbose, Json::Value& oJsonValue);
+    void writeParamToJson(Json::Value& oJsonValue, string field, string param, u_int32_t val);
+
     mlxCfgStatus genTLVsFile();
     mlxCfgStatus genXMLTemplate();
     mlxCfgStatus raw2XMLAux(bool isBin);
