@@ -52,6 +52,7 @@
 #endif
 
 #include <signal.h>
+#include "mft_utils/crc16.h"
 #include "tools_version.h"
 
 #ifndef __WIN__
@@ -394,6 +395,7 @@ typedef enum fs3_section
     FS4_STRN_IRON = 0xb5,
     FS4_STRN_TILE = 0xb6,
     FS4_MAIN_DATA = 0xd3,
+    FS4_FW_DEBUG_DUMP_2 = 0xd4,
     FS3_MFG_INFO = 0xe0,
     FS3_DEV_INFO = 0xe1,
     FS3_NV_DATA1 = 0xe2,
@@ -413,6 +415,7 @@ typedef enum fs3_section
     FS4_LC_INI2_TABLE = 0xf0,
     FS4_LC_INI_NV_DATA = 0xf1,
     FS4_CERT_CHAIN_0 = 0xf2,
+    FS5_SECURITY_LOG = 0xd5,
     FS4_DIGITAL_CACERT_RW = 0xf3,
     FS4_CERTIFICATE_CHAINS_1 = 0xf4,
     FS4_CERTIFICATE_CHAINS_2 = 0xf5,
@@ -556,28 +559,6 @@ private:
     int _errCode;
 };
 
-////////////////////////////////////////////////////////////////////////
-//                                                                    //
-// ****************************************************************** //
-//                        CRC16 CALCULATION                           //
-// ****************************************************************** //
-//                                                                    //
-////////////////////////////////////////////////////////////////////////
-class Crc16
-{
-public:
-    Crc16(bool d = false) : _debug(d) { clear(); }
-    u_int16_t get() { return _crc; }
-    void clear() { _crc = 0xffff; }
-    void operator<<(u_int32_t val) { add(val); }
-    void add(u_int32_t val);
-    void finish();
-
-private:
-    u_int16_t _crc;
-    bool _debug;
-};
-
 class u_int32_ba
 {
 public:
