@@ -34,12 +34,17 @@
 #include "fsctrl_ops.h"
 #include "fw_version.h"
 #include "fs_comps_ops.h"
+#include "mft_utils/mft_utils.h"
+#include "mlxdpa/certcontainerimp.h"
 
 #include <tools_utils.h>
 #include <bit_slice.h>
 
 #include <vector>
 
+#define REG_ID_MPIR 0x9059
+#define REG_ID_MRSV 0x9164
+
 bool FsCtrlOperations::unsupportedOperation()
 {
     if (_fsCtrlImgInfo.security_mode & SMM_SECURE_FW)
@@ -340,6 +345,53 @@ bool FsCtrlOperations::FsIntQuery()
         memcpy(_fwImgInfo.ext_info.vsd, fwQuery.deviceVsd, VSD_LEN);
     }
     (strncpy(_fsCtrlImgInfo.image_vsd, fwQuery.imageVsd, VSD_LEN));
+
+    bool mpir_reg_supported = false;
+    rc = isRegisterValidAccordingToMcamReg(mf, REG_ID_MPIR, &mpir_reg_supported);
+    if (rc != ME_OK)
+    {
+        return errmsg("error while reading MCAM reg. reported error code: %d", rc);
+    }
+
+    bool mrsv_reg_supported = false;
+    if (mpir_reg_supported)
+    {
+        struct reg_access_hca_mpir_ext mpir;
+        memset(&mpir, 0, sizeof(mpir));
+        rc = reg_access_mpir(mf, REG_ACCESS_METHOD_GET, &mpir);
+        if (rc == ME_OK)
+        {
+            _fsCtrlImgInfo.socket_direct = mpir.sdm;
+        } // ignoring case where rc != ME_OK since for ARM side of BF-3 we have to dynamically check what are the
+          // indexes of MPIR and not use zeroes as we did - which means read of MPIR will fail
+
+        if (_fsCtrlImgInfo.socket_direct)
+        {
+            rc = isRegisterValidAccordingToMcamReg(mf, REG_ID_MRSV, &mrsv_reg_supported);
+            if (rc != ME_OK)
+            {
+                return errmsg("error while reading MCAM reg. reported error code: %d", rc);
+            }
+        }
+    }
+
+    if (_fsCtrlImgInfo.socket_direct && (mrsv_reg_supported))
+    {
+        struct reg_access_hca_MRSV_ext mrsv;
+        memset(&mrsv, 0, sizeof(mrsv));
+        rc = reg_access_mrsv(mf, REG_ACCESS_METHOD_GET, &mrsv);
+        // MRSV reg is only supported for BF-3 so this is best effort that will only work on a BF-3 device
+        if (rc != ME_OK)
+        {
+            return errmsg("error while reading MRSV reg. reported error code: %d", rc);
+        }
+        if (mrsv.v) // mrsv.v -> MRSV reg is valid
+        {
+            _fsCtrlImgInfo.aux_card_connected = mrsv.data.MRSV_CX_7_Value_ext.two_p_core_active;
+            _fsCtrlImgInfo.is_aux_card_connected_valid = true;
+        }
+    }
+
     return true;
 }
 
@@ -475,18 +527,16 @@ bool FsCtrlOperations::FwVerifyAdv(ExtVerifyParams& verifyParams)
     }
     else
     {
-        FwOperations* imageOps = NULL;
-        if (!_createImageOps(&imageOps))
+        unique_ptr<FwOperations> imageOps = NULL;
+        if (!_createImageOps(imageOps))
         {
             return errmsg("%s", err());
         }
         if (!imageOps->FwVerify(verifyParams.verifyCallBackFunc, verifyParams.isStripedImage, verifyParams.showItoc,
                                 true))
         {
-            delete imageOps;
             return errmsg(imageOps->getErrorCode(), "%s", imageOps->err());
         }
-        delete imageOps;
     }
     return true;
 }
@@ -499,44 +549,22 @@ bool FsCtrlOperations::FwReadData(void* image, u_int32_t* image_size, bool verbo
     return errmsg("Read image is not supported");
 }
 
-bool FsCtrlOperations::ReadBootImage(void* image, u_int32_t* image_size, ProgressCallBackAdvSt* stProgressFunc)
+bool FsCtrlOperations::ReadMccComponent(vector<u_int8_t>& componentRawData,
+                                        FwComponent::comps_ids_t component,
+                                        ProgressCallBackAdvSt* stProgressFunc)
 {
-    if (image)
+    FwComponent comp;
+    if (!_fwCompsAccess->readComponent(component, comp, true, stProgressFunc))
     {
-        FwComponent bootImgComp;
-        if (!_fwCompsAccess->readComponent(FwComponent::COMPID_BOOT_IMG, bootImgComp, true,
-                                           (ProgressCallBackAdvSt*)stProgressFunc))
+        if (!_fwCompsAccess->readComponent(component, comp, false, stProgressFunc))
         {
-            if (!_fwCompsAccess->readComponent(FwComponent::COMPID_BOOT_IMG, bootImgComp, false,
-                                               (ProgressCallBackAdvSt*)stProgressFunc))
-            {
-                return errmsg(FwCompsErrToFwOpsErr(_fwCompsAccess->getLastError()),
-                              "Failed to read boot image, %s - RC[%d]", _fwCompsAccess->getLastErrMsg(),
-                              (int)_fwCompsAccess->getLastError());
-            }
+            return errmsg(FwCompsErrToFwOpsErr(_fwCompsAccess->getLastError()), "Failed to read component, %s - RC[%d]",
+                          _fwCompsAccess->getLastErrMsg(), (int)_fwCompsAccess->getLastError());
         }
-        *image_size = bootImgComp.getSize();
-        memcpy(image, bootImgComp.getData().data(), *image_size);
-        return true;
-    }
-    else
-    {
-        std::vector<FwComponent> compsMap;
-        if (!_fwCompsAccess->getFwComponents(compsMap, false))
-        {
-            return errmsg(FwCompsErrToFwOpsErr(_fwCompsAccess->getLastError()),
-                          "Failed to get the FW Components MAP, err[%d]", _fwCompsAccess->getLastError());
-        }
-        for (std::vector<FwComponent>::iterator it = compsMap.begin(); it != compsMap.end(); it++)
-        {
-            if (it->getType() == FwComponent::COMPID_BOOT_IMG)
-            {
-                *image_size = it->getSize();
-                return true;
-            }
-        }
-        return errmsg("Failed to get the Boot image");
     }
+    componentRawData.resize(comp.getData().size());
+    copy(comp.getData().begin(), comp.getData().end(), componentRawData.begin());
+    return true;
 }
 
 bool FsCtrlOperations::FwReadRom(std::vector<u_int8_t>& romSect)
@@ -626,27 +654,21 @@ bool FsCtrlOperations::VerifyAllowedParams(ExtBurnParams& burnParams, bool isSec
     return true;
 }
 
-bool FsCtrlOperations::_createImageOps(FwOperations** imageOps)
+bool FsCtrlOperations::_createImageOps(unique_ptr<FwOperations>& imageOps)
 {
-    u_int32_t imageSize = 0;
-    if (!ReadBootImage(NULL, &imageSize))
+    vector<u_int8_t> imageData;
+    if (!ReadMccComponent(imageData, FwComponent::COMPID_BOOT_IMG))
     {
         return errmsg("Failed to get boot image size");
     }
-    std::vector<u_int8_t> imageData;
-    imageData.resize(imageSize);
-    if (!ReadBootImage((void*)imageData.data(), &imageSize))
-    {
-        return errmsg("Failed to read boot image");
-    }
     fw_ops_params_t imageParams;
     memset(&imageParams, 0, sizeof(imageParams));
     imageParams.buffHndl = (u_int32_t*)imageData.data();
-    imageParams.buffSize = imageSize;
+    imageParams.buffSize = imageData.size();
     imageParams.hndlType = FHT_FW_BUFF;
     imageParams.ignoreCrcCheck = _fwParams.ignoreCrcCheck;
-    *imageOps = FwOperations::FwOperationsCreate(imageParams);
-    if (!(*imageOps))
+    imageOps = unique_ptr<FwOperations>(FwOperations::FwOperationsCreate(imageParams));
+    if (!(imageOps))
     {
         return errmsg("Failed to create image ops");
     }
@@ -844,7 +866,7 @@ bool FsCtrlOperations::burnEncryptedImage(FwOperations* imageOps, ExtBurnParams&
 
 bool FsCtrlOperations::isMultiAsicSystemComponent()
 {
-    if (_hwDevId == QUANTUM3_HW_ID || _hwDevId == CX8_HW_ID)
+    if (_hwDevId == QUANTUM3_HW_ID || _hwDevId == CX8_HW_ID ||  _hwDevId == CX9_HW_ID)
     {
         return true;
     }
