@@ -128,6 +128,7 @@ bool FwVersion::operator!=(const FwVersion& rhs) const
 // 30 is Spectrum3
 // 31 is Quantum2
 // 34 is Spectrum4
+// 35 is Quantum3
 bool FwVersion::is_switch_or_gb() const
 {
     if (_major == 0 && _minor == 0 && _subminor == 0 && !_devBranchTag.empty())
@@ -135,7 +136,7 @@ bool FwVersion::is_switch_or_gb() const
         return true;
     }
     if (_major == 11 || _major == 13 || _major == 15 || _major == 27 || _major == 29 || _major == 30 || _major == 31 ||
-        _major == 34 || _major == 19 || _major == 21)
+        _major == 34 || _major == 19 || _major == 21 || _major == 35)
     {
         return true;
     }
