@@ -80,6 +80,7 @@
 #define CX6LX_HW_ID 534
 #define CX7_HW_ID 536
 #define CX8_HW_ID 542
+#define CX9_HW_ID 549
 #define BF_HW_ID 529
 #define BF2_HW_ID 532
 #define BF3_HW_ID 540
@@ -116,6 +117,7 @@ typedef enum
 } LifeCycleFS5;
 
 #define MAX_HTOC_ENTRIES_NUM 28
+#define MAX_HTOC_ENTRIES_NUM_VERSION_1 64
 #define HASHES_TABLE_TAIL_SIZE 8
 #define HTOC_HASH_SIZE 64
 
@@ -312,6 +314,7 @@ typedef enum chip_type
     CT_CONNECTX6LX,
     CT_CONNECTX7,
     CT_CONNECTX8,
+    CT_CONNECTX9,
     CT_SPECTRUM3,
     CT_BLUEFIELD2,
     CT_BLUEFIELD3,
@@ -491,6 +494,9 @@ typedef struct fs3_info_ext
     u_int32_t ini_file_version;
     u_int8_t geo_address;
     bool geo_address_valid;
+    bool socket_direct;
+    bool aux_card_connected;
+    bool is_aux_card_connected_valid;
 
 } fs3_info_t;
 
@@ -531,6 +537,15 @@ typedef struct roms_info
     rom_info_t rom_info[MAX_ROMS_NUM];
 } roms_info_t;
 
+typedef enum
+{
+    BLANK = 0,
+    PRE_PROD_IPN = 1,
+    SECURE_IPN = 2,
+    PRE_PROD_OPN = 3,
+    SECURE_OPN = 4
+} device_sku;
+
 typedef struct fw_info_com
 {
     char psid[PSID_LEN + 1];
@@ -560,6 +575,7 @@ typedef struct fw_info_com
     u_int32_t burn_image_size; //! Be aware! This field is backward compatible starting from BB/CX-7
                                //! Use this field only for encrypted images
     u_int8_t dtoc_offset;
+    device_sku sku;
 } fw_info_com_t;
 
 typedef struct fw_info_ext
