@@ -566,8 +566,10 @@ public:
     void getSltpRegAndLeva(u_int32_t lane);
     u_int32_t getLaneSpeed(u_int32_t lane);
     void validateNumOfParamsForNDRGen();
+    void validateNumOfParamsForXDRGen();
     void checkSltpParamsSize();
     bool isMpeinjSupported();
+    u_int32_t getRateFromPptt();
 
     // Mlxlink params
     UserInput _userInput;
@@ -587,6 +589,7 @@ public:
     u_int32_t _cableLen;
     u_int32_t _activeSpeed;
     u_int32_t _activeSpeedEx;
+    u_int32_t _laneSpeedFromPptt;
     u_int32_t _protoCapability;
     u_int32_t _deviceCapability;
     u_int32_t _protoAdmin;
