@@ -34,7 +34,7 @@
 #define MLXLINK_ENUMS_H
 
 // Common definitions
-#define AMBER_VERSION "3.6"
+#define AMBER_VERSION "4.5"
 
 #define ACCESS_REG_MCIA "MCIA"
 #define ACCESS_REG_MDDQ "MDDQ"
@@ -85,6 +85,7 @@
 #define ACCESS_REG_SPAD "SPAD"
 #define ACCESS_REG_SPZR "SPZR"
 #define ACCESS_REG_MMCR "MMCR"
+#define ACCESS_REG_PPRM "PPRM"
 // define all used regs above this line
 
 #define QSFP_CHANNELS 4
@@ -583,6 +584,7 @@ enum PDDR_PAGES
     PDDR_TROUBLESHOOTING_INFO_PAGE = 1,
     PDDR_MODULE_INFO_PAGE = 3,
     PDDR_MODULE_LINK_DOWN_INFO_PAGE = 6,
+    PDDR_MODULE_LINK_UP_INFO_PAGE = 8,
     PDDR_MODULE_LATCHED_FLAG_INFO_PAGE = 9,
 };
 
@@ -601,9 +603,16 @@ enum GROUP_OPCODE
 
 enum PPCNT_GROUPS
 {
+    PPCNT_IEEE_802_3_COUNTERS_GROUP = 0x0,
     PPCNT_RFC_2863_GROUP = 0x1,
+    PPCNT_RFC_2819_GROUP = 0x2,
+    PPCNT_RFC_3635_GROUP = 0x3,
+    PPCNT_ETHERNET_EXTENDED_GROUP = 0x5,
     PPCNT_DISC_COUNTERS_GROUP = 0x6,
+    PPCNT_PER_PRIORITY_COUNTERS_GROUP = 0x10,
+    PPCNT_PER_TRAFFIC_CLASS_COUNTERS_GROUP = 0x11,
     PPCNT_PHY_GROUP = 0x12,
+    PPCNT_PER_TRAFFIC_CLASS_CONGESTION_COUNTERS_GROUP = 0x13,
     PPCNT_STATISTICAL_GROUP = 0x16,
     PPCNT_IB_PORT_COUNTERS_GROUP = 0x20,
     PPCNT_EXT_IB_PORT_COUNTERS_GROUP = 0x21,
@@ -641,7 +650,8 @@ enum PCIE_LINK_SPEED
     GEN2 = 2,
     GEN3 = 4,
     GEN4 = 16,
-    GEN5 = 32
+    GEN5 = 32,
+    GEN6 = 64
 };
 
 enum POWER_CLASS
@@ -814,12 +824,12 @@ enum SLTP_NDR
     SLTP_NDR_FIR_PRE1,
     SLTP_NDR_FIR_MAIN,
     SLTP_NDR_FIR_POST1,
+    SLTP_NDR_DRV_AMP,
     SLTP_NDR_LAST
 };
 
 enum SLTP_XDR
 {
-    SLTP_XDR_DRV_AMP,
     SLTP_XDR_TAP0,
     SLTP_XDR_TAP1,
     SLTP_XDR_TAP2,
@@ -832,6 +842,7 @@ enum SLTP_XDR
     SLTP_XDR_TAP9,
     SLTP_XDR_TAP10,
     SLTP_XDR_TAP11,
+    SLTP_XDR_DRV_AMP,
     SLTP_XDR_LAST
 };
 
@@ -859,13 +870,17 @@ enum FEC_MODE_ACTIVE
     FEC_MODE_FIRECODE_FEC = 1,
     FEC_MODE_STANDARD_RS_FEC_528_514 = 2,
     FEC_MODE_STANDARD_LL_FEC_271_257 = 3,
+    FEC_MODE_INTERLEAVED_QUAD_RS_FEC_544_514 = 4,
     FEC_MODE_INTERLEAVED_STANDARD_RS_FEC_544_514 = 6,
     FEC_MODE_STANDARD_RS_FEC_544_514 = 7,
+    FEC_MODE_ZERO_LATENCY_FEC = 8,
     FEC_MODE_RS_FEC_272_257 = 9,
     FEC_MODE_INTERLEAVED_RS_FEC_272_257 = 10,
+    FEC_MODE_INTERLEAVED_RS_FEC_544_514_PLR = 11,
     FEC_MODE_RS_FEC_544_514_PLR = 12,
     FEC_MODE_RS_FEC_271_257_PLR = 13,
     FEC_MODE_RS_FEC_PLR_272_257 = 14,
+    FEC_MODE_INTERLEAVED_RS_FEC_PLR_272_257 = 15
 };
 
 enum FEC_MODE_MASK
@@ -875,6 +890,7 @@ enum FEC_MODE_MASK
     FEC_MODE_MASK_FC = 0x2,
     FEC_MODE_MASK_RS_528 = 0x4,
     FEC_MODE_MASK_LL_271 = 0x8,
+    FEC_MODE_MASK_RS_544_514_QUAD = 0x10,
     FEC_MODE_MASK_DF_RS = 0x40,
     FEC_MODE_MASK_RS_544 = 0x80,
     FEC_MODE_MASK_LL_272 = 0x200,
@@ -1526,10 +1542,13 @@ enum ETH_LINK_SPEED_EXT
     ETH_LINK_SPEED_EXT_100GAUI_1 = 0x800,
     ETH_LINK_SPEED_EXT_200GAUI_4 = 0x1000,
     ETH_LINK_SPEED_EXT_200GAUI_2 = 0x2000,
-    ETH_LINK_SPEED_EXT_Reserved_14 = 0x4000,
+    ETH_LINK_SPEED_EXT_200GAUI_1 = 0x4000,
     ETH_LINK_SPEED_EXT_400GAUI_8 = 0x8000,
     ETH_LINK_SPEED_EXT_400GAUI_4 = 0x10000,
+    ETH_LINK_SPEED_EXT_400GAUI_2 = 0x20000,
     ETH_LINK_SPEED_EXT_800GAUI_8 = 0x80000,
+    ETH_LINK_SPEED_EXT_800GAUI_4 = 0x100000,
+    ETH_LINK_SPEED_EXT_1_6TAUI_8 = 0x800000,
     ETH_LINK_SPEED_EXT_SGMII_10M = 0x8000000
 };
 
@@ -1560,7 +1579,9 @@ enum NVLINK_SPEED
     NVLINK_SPEED_XDR = 0x100
 };
 
-#define LINK_SPEED_200G_LANE IB_LINK_SPEED_XDR
+#define LINK_SPEED_200G_LANE                                                                                          \
+    (IB_LINK_SPEED_XDR | ETH_LINK_SPEED_EXT_200GAUI_1 | ETH_LINK_SPEED_EXT_400GAUI_2 | ETH_LINK_SPEED_EXT_800GAUI_4 | \
+     ETH_LINK_SPEED_EXT_1_6TAUI_8)
 
 #define LINK_SPEED_100G_LANE (IB_LINK_SPEED_NDR | ETH_LINK_SPEED_100G_LANE)
 
@@ -1679,6 +1700,7 @@ enum AMBER_SHEET
     AMBER_SHEET_PHY_DEBUG_INFO = 15,
     AMBER_SHEET_EXT_MODULE_STATUS = 16,
     AMBER_SHEET_SERDES_5NM = 17,
+    AMBER_SHEET_RECOVERY_COUNTERS = 20,
     AMBER_SHEET_ALL // Keep this enum last
 };
 
@@ -1838,4 +1860,68 @@ enum LOCAL_REASON_OPCODE
     LOCAL_REASON_OPCODE_RESERVED = 0xE4,
 };
 
+enum UP_REASON_PWR
+{
+    UP_REASON_PWR_NO_DOWN_COMMAND = 0,
+    UP_REASON_PWR_KEEP_LINK_UP_ON_BOOT = 0x1,
+    UP_REASON_PWR_KEEP_LINK_UP_ETH_IB = 0x2,
+    UP_REASON_PWR_KEEP_LINK_UP_ON_STANDBY = 0x3,
+};
+
+enum UP_REASON_DRV
+{
+    UP_REASON_DRV_NO_DOWN_COMMAND = 0,
+    UP_REASON_DRV_UP_BY_AT_LEAST_ONE_OF_THE_HOSTS = 0x1,
+};
+
+enum UP_REASON_MNG
+{
+    UP_REASON_MNG_NO_DOWN_COMMAND = 0,
+    UP_REASON_MNG_BMC_FORCE_LINKUP = 0x1,
+    UP_REASON_MNG_WOL_FORCE_LINKUP = 0x2,
+    UP_REASON_MNG_ANS_FORCE_LINKUP = 0x3,
+};
+
+enum FAST_LINK_UP_STATUS
+{
+    FAST_LINK_UP_STATUS_UNKOWN = 0,
+    FAST_LINK_UP_STATUS_FAST_LINKUP_WAS_PERFORMED = 0x1,
+    FAST_LINK_UP_STATUS_REGULAR_LINK_UP_DUE_CABLE_CHANGE = 0x2,
+    FAST_LINK_UP_STATUS_REGULAR_LINK_UP_DUE_PROTOCOL_CHANGE = 0x3,
+    FAST_LINK_UP_STATUS_REGULAR_LINK_UP_DUE_NON_FASTBOOT = 0x4,
+    FAST_LINK_UP_STATUS_REGULAR_LINK_UP_DUE_CABLE_MLPN_FLOW = 0x5,
+    FAST_LINK_UP_STATUS_REGULAR_LINK_UP_DUE_CABLE_MLPN_PCNR = 0x6,
+    FAST_LINK_UP_STATUS_INVALID_FASTBOOT = 0x7,
+};
+
+enum PPRM_OPERATION_RECOVERY
+{
+    PPRM_OPERATION_RECOVERY_HOST_LOG = 0,
+    PPRM_OPERATION_RECOVERY_HOST_SERDES = 2,
+    PPRM_OPERATION_RECOVERY_MODULE_TX = 4,
+    PPRM_OPERATION_RECOVERY_MODULE_DATA_PATH = 8
+};
+
+enum PPTT_PARAMS
+{
+    LANE_RATE_ADMIN
+};
+enum PPTT_SPEED_MASK
+{
+    PPTT_SDR,
+    PPTT_DDR,
+    PPTT_QDR,
+    PPTT_FDR10,
+    PPTT_FDR,
+    PPTT_EDR,
+    PPTT_HDR,
+    PPTT_NDR,
+    PPTT_XDR,
+    PPTT_RESERVED,
+    PPTT_1GE,
+    PPTT_XAUI,
+    PPTT_50GE_KR4,
+    PPTT_SPEED_MASK_MAX
+};
+
 #endif /* MLXLINK_ENUMS_H */
