@@ -60,8 +60,8 @@ public:
     void setDefaultFields(const string& regName, const string& fieldsStr);
     void sendPrmReg(const string& regName, maccess_reg_method_t method, const char* fields, ...);
     void sendPrmReg(const string& regName, maccess_reg_method_t method);
-    virtual u_int32_t getFieldValue(string field_name);
-    string getFieldStr(const string& field);
+    virtual u_int32_t getFieldValue(string field_name, u_int32_t size = 0);
+    string getFieldStr(const string& field, const u_int32_t size = 0);
     string getRawFieldValueStr(const string fieldName);
     u_int32_t getFieldSize(string field_name);
     string getAscii(const string& name, u_int32_t size = 4);
