@@ -288,6 +288,22 @@ string EthSupportedSpeeds2Str(u_int32_t int_mask)
 string EthExtSupportedSpeeds2Str(u_int32_t int_mask)
 {
     string maskStr = "";
+    if (int_mask & ETH_LINK_SPEED_EXT_200GAUI_1)
+    {
+        maskStr += "200G_1X,";
+    }
+    if (int_mask & ETH_LINK_SPEED_EXT_400GAUI_2)
+    {
+        maskStr += "400G_2X,";
+    }
+    if (int_mask & ETH_LINK_SPEED_EXT_800GAUI_4)
+    {
+        maskStr += "800G_4X,";
+    }
+    if (int_mask & ETH_LINK_SPEED_EXT_1_6TAUI_8)
+    {
+        maskStr += "1600G_8X,";
+    }
     if (int_mask & ETH_LINK_SPEED_EXT_800GAUI_8)
     {
         maskStr += "800G_8X,";
@@ -1381,9 +1397,12 @@ bool isSpeed200GPerLane(u_int32_t speed, u_int32_t protocol)
 
 bool isNRZSpeed(u_int32_t speed, u_int32_t protocol)
 {
-    return isSpeed25GPerLane(speed, protocol) ||
-           !(isSpeed50GPerLane(speed, protocol) || isSpeed100GPerLane(speed, protocol) ||
-             isSpeed200GPerLane(speed, protocol));
+    // this twisted condition was made due to 100G per lane and 25G per lane share a mutual bit (19) and causes the 100G
+    // per lane to be recognized as 25G per lane.
+    return !isSpeed100GPerLane(speed, protocol) &&
+           (isSpeed25GPerLane(speed, protocol) ||
+            !(isSpeed50GPerLane(speed, protocol) || isSpeed100GPerLane(speed, protocol) ||
+              isSpeed200GPerLane(speed, protocol) || isSpeed25GPerLane(speed, protocol)));
 }
 
 string linkWidthMaskToStr(u_int32_t width)
