@@ -152,6 +152,10 @@
 #define ARCH_arm6l
 #elif defined(__riscv)
 #define ARCH_riscv
+#elif defined(__loongarch_lp64)
+#define ARCH_loongarch64
+#elif defined(__e2k__)
+#define ARCH_e2k
 #else
 #error Unknown CPU architecture using the linux OS
 #endif
