@@ -37,31 +37,33 @@ extern "C"
 {
 #endif
 
-// #include <tools_layouts/reg_access_hca_layouts.h>
-// #include <tools_layouts/reg_access_switch_layouts.h>
+/* #include <tools_layouts/reg_access_hca_layouts.h> */
+/* #include <tools_layouts/reg_access_switch_layouts.h> */
 #include "reg_access_common.h"
+#include "common/bit_slice.h"
+#define MCAM_REG_GROUPS_AMOUNT 4
 
-enum
-{ // header lengths in bytes
+
+enum { /* header lengths in bytes */
     REG_ACCESS_MFBA_HEADER_LEN = 12,
 };
 
-typedef enum
-{
-    MDDT_PRM_REGISTER_CMD_TYPE = 0,
-    MDDT_COMMAND_CMD_TYPE = 1,
+typedef enum {
+    MDDT_PRM_REGISTER_CMD_TYPE   = 0,
+    MDDT_COMMAND_CMD_TYPE        = 1,
     MDDT_CRSPACE_ACCESS_CMD_TYPE = 2
 } mddt_command_type_t;
 
-// we use the same error messages as mtcr
+/* we use the same error messages as mtcr */
 typedef MError reg_access_status_t;
 
-// Add new methods here
+/* Add new methods here */
 struct reg_access_switch_mddq_ext;
 reg_access_status_t reg_access_mddq(mfile* mf, reg_access_method_t method, struct reg_access_switch_mddq_ext* mddq);
 struct reg_access_switch_mddt_reg_ext;
-reg_access_status_t
-  reg_access_mddt(mfile* mf, reg_access_method_t method, struct reg_access_switch_mddt_reg_ext* switch_mddt_reg);
+reg_access_status_t reg_access_mddt(mfile                                * mf,
+                                    reg_access_method_t                    method,
+                                    struct reg_access_switch_mddt_reg_ext* switch_mddt_reg);
 struct reg_access_hca_paos_reg_ext;
 reg_access_status_t reg_access_paos(mfile* mf, reg_access_method_t method, struct reg_access_hca_paos_reg_ext* paos);
 
@@ -74,33 +76,36 @@ reg_access_status_t reg_access_mtmp(mfile* mf, reg_access_method_t method, struc
 struct reg_access_hca_mtcap_ext;
 reg_access_status_t reg_access_mtcap(mfile* mf, reg_access_method_t method, struct reg_access_hca_mtcap_ext* mtcap);
 struct reg_access_switch_pmaos_reg_ext;
-reg_access_status_t
-  reg_access_pmaos(mfile* mf, reg_access_method_t method, struct reg_access_switch_pmaos_reg_ext* pmaos);
+reg_access_status_t reg_access_pmaos(mfile                                 * mf,
+                                     reg_access_method_t                     method,
+                                     struct reg_access_switch_pmaos_reg_ext* pmaos);
 struct reg_access_hca_pmlp_reg_ext;
 reg_access_status_t reg_access_pmlp(mfile* mf, reg_access_method_t method, struct reg_access_hca_pmlp_reg_ext* pmlp);
 struct reg_access_hca_mnvgc_reg_ext;
-reg_access_status_t
-  reg_access_mnvgc(mfile* mf, reg_access_method_t method, struct reg_access_hca_mnvgc_reg_ext* mnvgc);
+reg_access_status_t reg_access_mnvgc(mfile* mf, reg_access_method_t method,
+                                     struct reg_access_hca_mnvgc_reg_ext* mnvgc);
 struct reg_access_hca_mmdio_ext;
 reg_access_status_t reg_access_mmdio(mfile* mf, reg_access_method_t method, struct reg_access_hca_mmdio_ext* mmdio);
 struct tools_mjtag;
 reg_access_status_t reg_access_mjtag(mfile* mf, reg_access_method_t method, struct tools_mjtag* mjtag);
 struct tools_open_mnvda;
 reg_access_status_t reg_access_mnvda(mfile* mf, reg_access_method_t method, struct tools_open_mnvda* mnvda);
-    struct tools_open_mnvdi;
-    reg_access_status_t reg_access_mnvdi(mfile* mf, reg_access_method_t method, struct tools_open_mnvdi* mnvdi);
+struct tools_open_mnvdi;
+reg_access_status_t reg_access_mnvdi(mfile* mf, reg_access_method_t method, struct tools_open_mnvdi* mnvdi);
 struct reg_access_hca_mnvia_reg_ext;
-reg_access_status_t
-  reg_access_mnvia(mfile* mf, reg_access_method_t method, struct reg_access_hca_mnvia_reg_ext* mnvia);
+reg_access_status_t reg_access_mnvia(mfile* mf, reg_access_method_t method,
+                                     struct reg_access_hca_mnvia_reg_ext* mnvia);
 struct reg_access_hca_mnvqc_reg_ext;
-reg_access_status_t
-  reg_access_mnvqc(mfile* mf, reg_access_method_t method, struct reg_access_hca_mnvqc_reg_ext* mnvqc);
+reg_access_status_t reg_access_mnvqc(mfile* mf, reg_access_method_t method,
+                                     struct reg_access_hca_mnvqc_reg_ext* mnvqc);
 struct tools_open_mnvgn;
-reg_access_status_t
-  reg_access_mnvgn(mfile* mf, reg_access_method_t method, struct tools_open_mnvgn* mnvgn, int* status);
+reg_access_status_t reg_access_mnvgn(mfile* mf, reg_access_method_t method, struct tools_open_mnvgn* mnvgn,
+                                     int* status);
 struct tools_open_mgnle;
-reg_access_status_t
-  reg_access_mgnle(mfile* mf, reg_access_method_t method, struct tools_open_mgnle* mngnle, int* status);
+reg_access_status_t reg_access_mgnle(mfile                  * mf,
+                                     reg_access_method_t      method,
+                                     struct tools_open_mgnle* mngnle,
+                                     int                    * status);
 struct switchen_ritr;
 reg_access_status_t reg_access_ritr(mfile* mf, reg_access_method_t method, struct switchen_ritr* ritr);
 struct switchen_ricnt;
@@ -118,10 +123,12 @@ struct reg_access_hca_resource_dump_ext;
 /*********************** ATTENTION *************************/
 /** The registers below must be same (except for the ID) ***/
 /** Changes in them should be made both in switch and nic **/
-reg_access_status_t
-  reg_access_res_dump(mfile* mf, reg_access_method_t method, struct reg_access_hca_resource_dump_ext* res_dump);
-reg_access_status_t
-  reg_access_mord(mfile* mf, reg_access_method_t method, struct reg_access_hca_resource_dump_ext* res_dump);
+reg_access_status_t reg_access_res_dump(mfile                                  * mf,
+                                        reg_access_method_t                      method,
+                                        struct reg_access_hca_resource_dump_ext* res_dump);
+reg_access_status_t reg_access_mord(mfile                                  * mf,
+                                    reg_access_method_t                      method,
+                                    struct reg_access_hca_resource_dump_ext* res_dump);
 
 struct switchen_ppcnt_reg;
 reg_access_status_t reg_access_ppcnt(mfile* mf, reg_access_method_t method, struct switchen_ppcnt_reg* ricnt);
@@ -135,8 +142,8 @@ struct tools_mdrcr;
 reg_access_status_t reg_access_mdrcr(mfile* mf, reg_access_method_t method, struct tools_mdrcr* mdrcr);
 
 struct reg_access_switch_icam_reg_ext;
-reg_access_status_t
-  reg_access_icam(mfile* mf, reg_access_method_t method, struct reg_access_switch_icam_reg_ext* icam);
+reg_access_status_t reg_access_icam(mfile* mf, reg_access_method_t method,
+                                    struct reg_access_switch_icam_reg_ext* icam);
 struct reg_access_switch_icsr_ext;
 reg_access_status_t reg_access_icsr(mfile* mf, reg_access_method_t method, struct reg_access_switch_icsr_ext* icsr);
 
@@ -156,19 +163,19 @@ struct cibfw_register_mfai;
 reg_access_status_t reg_access_mfai(mfile* mf, reg_access_method_t method, struct cibfw_register_mfai* mfai);
 struct tools_open_mvts;
 reg_access_status_t reg_access_mvts(mfile* mf, reg_access_method_t method, struct tools_open_mvts* mvts);
-    struct reg_access_switch_mfmc_reg_ext;
-    reg_access_status_t
-      reg_access_mfmc(mfile* mf, reg_access_method_t method, struct reg_access_switch_mfmc_reg_ext* mfmc);
+struct reg_access_switch_mfmc_reg_ext;
+reg_access_status_t reg_access_mfmc(mfile* mf, reg_access_method_t method,
+                                    struct reg_access_switch_mfmc_reg_ext* mfmc);
 struct reg_access_hca_mfpa_reg_ext;
-reg_access_status_t
-  reg_access_mfpa_new(mfile* mf, reg_access_method_t method, struct reg_access_hca_mfpa_reg_ext* mfpa);
+reg_access_status_t reg_access_mfpa_new(mfile* mf, reg_access_method_t method,
+                                        struct reg_access_hca_mfpa_reg_ext* mfpa);
 struct reg_access_hca_mcam_reg_ext;
 reg_access_status_t reg_access_mcam(mfile* mf, reg_access_method_t method, struct reg_access_hca_mcam_reg_ext* mcam);
 struct tools_open_mlock;
 reg_access_status_t reg_access_secure_host(mfile* mf, reg_access_method_t method, struct tools_open_mlock* mlock);
 /*
-  * MCXX new burn commands
-  */
+ * MCXX new burn commands
+ */
 struct reg_access_hca_mcda_reg_ext;
 reg_access_status_t reg_access_mcda(mfile* mf, reg_access_method_t method, struct reg_access_hca_mcda_reg_ext* mcda);
 struct reg_access_hca_mqis_reg_ext;
@@ -182,55 +189,59 @@ reg_access_status_t reg_access_mcqi(mfile* mf, reg_access_method_t method, struc
 struct reg_access_hca_mgir_ext;
 reg_access_status_t reg_access_mgir(mfile* mf, reg_access_method_t method, struct reg_access_hca_mgir_ext* mgir);
 struct reg_access_hca_mtrc_cap_reg_ext;
-reg_access_status_t
-  reg_access_mtrc_cap(mfile* mf, reg_access_method_t method, struct reg_access_hca_mtrc_cap_reg_ext* mtrc_cap);
-    struct reg_access_hca_mtrc_conf_reg_ext;
-    reg_access_status_t
-      reg_access_mtrc_conf(mfile* mf, reg_access_method_t method, struct reg_access_hca_mtrc_conf_reg_ext* mtrc_conf);
+reg_access_status_t reg_access_mtrc_cap(mfile                                 * mf,
+                                        reg_access_method_t                     method,
+                                        struct reg_access_hca_mtrc_cap_reg_ext* mtrc_cap);
+struct reg_access_hca_mtrc_conf_reg_ext;
+reg_access_status_t reg_access_mtrc_conf(mfile                                  * mf,
+                                         reg_access_method_t                      method,
+                                         struct reg_access_hca_mtrc_conf_reg_ext* mtrc_conf);
 struct reg_access_hca_mtrc_stdb_reg_ext;
-reg_access_status_t
-  reg_access_mtrc_stdb_wrapper(mfile* mf, u_int32_t read_size, u_int8_t string_db_index, char* buffer);
-    struct reg_access_hca_mtrc_ctrl_reg_ext;
-    reg_access_status_t
-      reg_access_mtrc_ctrl(mfile* mf, reg_access_method_t method, struct reg_access_hca_mtrc_ctrl_reg_ext* mtrc_ctrl);
+reg_access_status_t reg_access_mtrc_stdb_wrapper(mfile* mf, u_int32_t read_size, u_int8_t string_db_index,
+                                                 char* buffer);
+struct reg_access_hca_mtrc_ctrl_reg_ext;
+reg_access_status_t reg_access_mtrc_ctrl(mfile                                  * mf,
+                                         reg_access_method_t                      method,
+                                         struct reg_access_hca_mtrc_ctrl_reg_ext* mtrc_ctrl);
 struct tools_open_mcdd_reg;
 reg_access_status_t reg_access_mcdd(mfile* mf, reg_access_method_t method, struct tools_open_mcdd_reg* mcdd);
 const char* reg_access_err2str(reg_access_status_t status);
 struct tools_open_mirc_reg;
 reg_access_status_t reg_access_mirc(mfile* mf, reg_access_method_t method, struct tools_open_mirc_reg* mirc);
 
-    struct reg_access_switch_plib_reg_ext;
-    reg_access_status_t
-      reg_access_plib(mfile* mf, reg_access_method_t method, struct reg_access_switch_plib_reg_ext* plib);
+struct reg_access_switch_plib_reg_ext;
+reg_access_status_t reg_access_plib(mfile* mf, reg_access_method_t method,
+                                    struct reg_access_switch_plib_reg_ext* plib);
 
-    struct reg_access_hca_mteim_reg_ext;
-    reg_access_status_t
-      reg_access_mteim(mfile* mf, reg_access_method_t method, struct reg_access_hca_mteim_reg_ext* mteim);
+struct reg_access_hca_mteim_reg_ext;
+reg_access_status_t reg_access_mteim(mfile* mf, reg_access_method_t method,
+                                     struct reg_access_hca_mteim_reg_ext* mteim);
 
-    struct reg_access_hca_mtie_ext;
-    reg_access_status_t reg_access_mtie(mfile* mf, reg_access_method_t method, struct reg_access_hca_mtie_ext* mtie);
-    struct reg_access_hca_mtim_ext;
-    reg_access_status_t reg_access_mtim(mfile* mf, reg_access_method_t method, struct reg_access_hca_mtim_ext* mtim);
-    struct reg_access_hca_mtdc_ext;
-    reg_access_status_t reg_access_mtdc(mfile* mf, reg_access_method_t method, struct reg_access_hca_mtdc_ext* mtdc);
+struct reg_access_hca_mtie_ext;
+reg_access_status_t reg_access_mtie(mfile* mf, reg_access_method_t method, struct reg_access_hca_mtie_ext* mtie);
+struct reg_access_hca_mtim_ext;
+reg_access_status_t reg_access_mtim(mfile* mf, reg_access_method_t method, struct reg_access_hca_mtim_ext* mtim);
+struct reg_access_hca_mtdc_ext;
+reg_access_status_t reg_access_mtdc(mfile* mf, reg_access_method_t method, struct reg_access_hca_mtdc_ext* mtdc);
 
-    struct reg_access_hca_debug_cap;
-    reg_access_status_t
-      reg_access_debug_cap(mfile* mf, reg_access_method_t method, struct reg_access_hca_debug_cap* debug_cap);
+struct reg_access_hca_debug_cap;
+reg_access_status_t reg_access_debug_cap(mfile                          * mf,
+                                         reg_access_method_t              method,
+                                         struct reg_access_hca_debug_cap* debug_cap);
 
 struct reg_access_switch_mkdc_reg_ext;
-reg_access_status_t
-  reg_access_mkdc(mfile* mf, reg_access_method_t method, struct reg_access_switch_mkdc_reg_ext* mkdc);
+reg_access_status_t reg_access_mkdc(mfile* mf, reg_access_method_t method,
+                                    struct reg_access_switch_mkdc_reg_ext* mkdc);
 struct reg_access_switch_mtcq_reg_ext;
-reg_access_status_t
-  reg_access_mtcq(mfile* mf, reg_access_method_t method, struct reg_access_switch_mtcq_reg_ext* mtcq);
+reg_access_status_t reg_access_mtcq(mfile* mf, reg_access_method_t method,
+                                    struct reg_access_switch_mtcq_reg_ext* mtcq);
 struct reg_access_switch_mdsr_reg_ext;
-reg_access_status_t
-  reg_access_mdsr(mfile* mf, reg_access_method_t method, struct reg_access_switch_mdsr_reg_ext* mtcq);
+reg_access_status_t reg_access_mdsr(mfile* mf, reg_access_method_t method,
+                                    struct reg_access_switch_mdsr_reg_ext* mtcq);
 struct reg_access_hca_nic_cap_ext_reg_ext;
-reg_access_status_t reg_access_nic_cap_ext(mfile* mf,
-                                            reg_access_method_t method,
-                                            struct reg_access_hca_nic_cap_ext_reg_ext* nic_cap_ext);
+reg_access_status_t reg_access_nic_cap_ext(mfile                                    * mf,
+                                           reg_access_method_t                        method,
+                                           struct reg_access_hca_nic_cap_ext_reg_ext* nic_cap_ext);
 struct reg_access_switch_mrsr_ext;
 reg_access_status_t reg_access_mrsr(mfile* mf, reg_access_method_t method, struct reg_access_switch_mrsr_ext* mrsr);
 
@@ -238,31 +249,51 @@ struct reg_access_hca_dtor_reg_ext;
 reg_access_status_t reg_access_dtor(mfile* mf, reg_access_method_t method, struct reg_access_hca_dtor_reg_ext* dtor);
 
 struct reg_access_hca_nic_dpa_eug_reg_ext;
-reg_access_status_t reg_access_nic_dpa_eug(mfile* mf,
-                                            reg_access_method_t method,
-                                            struct reg_access_hca_nic_dpa_eug_reg_ext* nic_dpa_eug);
+reg_access_status_t reg_access_nic_dpa_eug(mfile                                    * mf,
+                                           reg_access_method_t                        method,
+                                           struct reg_access_hca_nic_dpa_eug_reg_ext* nic_dpa_eug);
 struct reg_access_hca_mpegc_reg_ext;
-reg_access_status_t reg_access_mpegc(mfile* mf, reg_access_method_t method, struct reg_access_hca_mpegc_reg_ext* mpegc);
+reg_access_status_t reg_access_mpegc(mfile* mf, reg_access_method_t method,
+                                     struct reg_access_hca_mpegc_reg_ext* mpegc);
 
 struct reg_access_hca_nic_dpa_perf_reg_ext;
-reg_access_status_t reg_access_nic_dpa_perf(mfile* mf,
-                                            reg_access_method_t method,
+reg_access_status_t reg_access_nic_dpa_perf(mfile                                     * mf,
+                                            reg_access_method_t                         method,
                                             struct reg_access_hca_nic_dpa_perf_reg_ext* nic_dpa_perf);
 struct reg_access_hca_nic_dpa_perf_ctrl_reg_ext;
-reg_access_status_t reg_access_nic_dpa_perf_ctrl(mfile* mf,
-                                                  reg_access_method_t method,
-                                                  struct reg_access_hca_nic_dpa_perf_ctrl_reg_ext* nic_dpa_perf_ctrl);
+reg_access_status_t reg_access_nic_dpa_perf_ctrl(mfile                                          * mf,
+                                                 reg_access_method_t                              method,
+                                                 struct reg_access_hca_nic_dpa_perf_ctrl_reg_ext* nic_dpa_perf_ctrl);
 struct reg_access_hca_nic_dpa_eu_partition_reg_ext;
-reg_access_status_t
-  reg_access_nic_dpa_eu_partition(mfile* mf,
-                                  reg_access_method_t method,
-                                  struct reg_access_hca_nic_dpa_eu_partition_reg_ext* nic_dpa_eu_partition);
+reg_access_status_t reg_access_nic_dpa_eu_partition(mfile                                             * mf,
+                                                    reg_access_method_t                                 method,
+                                                    struct reg_access_hca_nic_dpa_eu_partition_reg_ext* nic_dpa_eu_partition);
 struct reg_access_hca_pguid_reg_ext;
-reg_access_status_t
-  reg_access_pguid(mfile* mf, reg_access_method_t method, struct reg_access_hca_pguid_reg_ext* pguid);
+reg_access_status_t reg_access_pguid(mfile* mf, reg_access_method_t method,
+                                     struct reg_access_hca_pguid_reg_ext* pguid);
+
+struct reg_access_hca_mroq_ext;
+reg_access_status_t reg_access_mroq(mfile* mf, reg_access_method_t method, struct reg_access_hca_mroq_ext* mroq);
+
+struct reg_access_hca_mpir_ext;
+reg_access_status_t reg_access_mpir(mfile* mf, reg_access_method_t method, struct reg_access_hca_mpir_ext* mpir);
+
+struct reg_access_hca_MRSV_ext;
+reg_access_status_t reg_access_mrsv(mfile* mf, reg_access_method_t method, struct reg_access_hca_MRSV_ext* mrsv);
+
+/* MCAM - functions and constants to extract valid bit in a more generic way */
+static const unsigned int REG_ACCESS_BASE_GROUP_0_ID = 0x9000;
+static const unsigned int REG_ACCESS_BASE_GROUP_1_ID = 0x9080;
+static const unsigned int REG_ACCESS_BASE_GROUP_2_ID = 0x9100;
+static const unsigned int REG_ACCESS_BASE_GROUP_3_ID = 0x9180;
+static const unsigned int MAX_REG_ACCESS_ID = 0x91FF;
+static const unsigned int REG_GROUP_LEN = 0x80;
+
+reg_access_status_t getIndexOfRegGroup(unsigned int reg_id, int* idx);
+reg_access_status_t isRegisterValidAccordingToMcamReg(mfile* mf, unsigned int reg_id, bool* is_reg_valid);
 
 #ifdef __cplusplus
 }
 #endif
 
-#endif // REG_ACCESS_H
+#endif /* REG_ACCESS_H */
